Package: IntEREst
Title: Intron-Exon Retention Estimator
Version: 1.37.0
Date: 2024-03-19
Author: Ali Oghabian <Ali.Oghabian@Helsinki.Fi>, Dario Greco
        <dario.greco@helsinki.fi>, Mikko Frilander
        <Mikko.Frilander@helsinki.fi>
Maintainer: Ali Oghabian <Ali.Oghabian@Helsinki.Fi>
Description: This package performs Intron-Exon Retention analysis on
        RNA-seq data (.bam files).
Depends: R (>= 3.5.0), GenomicRanges, Rsamtools, SummarizedExperiment,
        edgeR, S4Vectors, GenomicFiles
Imports: seqLogo, Biostrings, GenomicFeatures (>= 1.39.4), txdbmaker,
        IRanges, seqinr, graphics, grDevices, stats, utils, grid,
        methods, DBI, RMariaDB, GenomicAlignments, BiocParallel,
        BiocGenerics, DEXSeq, DESeq2
Suggests: clinfun, knitr, rmarkdown, BSgenome.Hsapiens.UCSC.hg19
VignetteBuilder: knitr
LazyData: true
biocViews: Software, AlternativeSplicing, Coverage,
        DifferentialSplicing, Sequencing, RNASeq, Alignment,
        Normalization, DifferentialExpression, ImmunoOncology
License: GPL-2
NeedsCompilation: no
git_url: https://git.bioconductor.org/packages/IntEREst
git_branch: devel
git_last_commit: 9e02eb2
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
Packaged: 2026-04-28 23:20:04 UTC; biocbuild
