interest.sequential <-
function(
	bamFileYieldSize=1000000,
	bamFile,
	isPaired,
	isPairedDuplicate=FALSE,
	isSingleReadDuplicate=NA,
	reference,
	referenceGeneNames,
	referenceIntronExon,
	repeatsTableToFilter=c(),
	junctionReadsOnly=FALSE,
	outFile,
	logFile="",
	returnObj=FALSE,
	method=c("ExEx", "IntRet", "IntSpan", "ExSkip"),
	strandSpecific,
	appendLogFile=FALSE,
	sampleName=c(), 
	scaleLength= c(TRUE,FALSE), 
	scaleFragment= c(TRUE,TRUE),
	limitRanges=GRanges(),
	excludeFusionReads=FALSE,
	loadLimitRangesReads=FALSE,
	... ){

  interest(
      bamFileYieldSize=bamFileYieldSize, 
      bamFile=bamFile,
      isPaired=isPaired,
      isPairedDuplicate=isPairedDuplicate,
      isSingleReadDuplicate=isSingleReadDuplicate,
      reference=reference, 
      referenceGeneNames=referenceGeneNames,
      referenceIntronExon=referenceIntronExon, 
      repeatsTableToFilter=repeatsTableToFilter,
      junctionReadsOnly=junctionReadsOnly, 
      outFile=outFile, 
      logFile=logFile,
      returnObj=returnObj, 
      method=method,
      strandSpecific=strandSpecific,
      appendLogFile=appendLogFile, 
      sampleName=sampleName, 
      scaleLength= scaleLength, scaleFragment= scaleFragment, 
      limitRanges=limitRanges, 
      excludeFusionReads=excludeFusionReads,
      loadLimitRangesReads=loadLimitRangesReads,
      ...)
  
  
}
