nohup fastq-dump -I --split-files SRR1691633.sra &
nohup fastq-dump -I --split-files SRR1691634.sra &
nohup fastq-dump -I --split-files SRR1691635.sra &
nohup fastq-dump -I --split-files SRR1691636.sra &
nohup fastq-dump -I --split-files SRR1691637.sra &
nohup fastq-dump -I --split-files SRR1691638.sra &
nohup fastq-dump -I --split-files SRR1691639.sra &
nohup fastq-dump -I --split-files SRR1691640.sra &
nohup fastq-dump -I --split-files SRR1691641.sra &
nohup fastq-dump -I --split-files SRR1691642.sra &
nohup fastq-dump -I --split-files SRR1691643.sra &
nohup fastq-dump -I --split-files SRR1691644.sra &
nohup fastq-dump -I --split-files SRR1691645.sra &
nohup fastq-dump -I --split-files SRR1691646.sra &
nohup fastq-dump -I --split-files SRR1691647.sra &
nohup fastq-dump -I --split-files SRR1691648.sra &
nohup fastq-dump -I --split-files SRR1691649.sra &
nohup fastq-dump -I --split-files SRR1691650.sra &
nohup fastq-dump -I --split-files SRR1691651.sra &
nohup fastq-dump -I --split-files SRR1691652.sra &
nohup fastq-dump -I --split-files SRR1691653.sra &
nohup fastq-dump -I --split-files SRR1691654.sra &
